LdSubmitController<T, Arg> class
Handles the lifecyle of a submit action. Pass a LdSubmitConfig to the controller to configure the submit action. Updated LdSubmitController that uses LdRetryController
- Mixed-in types
Constructors
-
LdSubmitController({required LdSubmitConfig<
T, Arg> config, ValueNotifier<Arg?> ? arg})
Properties
-
arg
↔ ValueNotifier<
Arg?> ? -
getter/setter pair
- canCancel → bool
-
no setter
- canRetry → bool
-
no setter
- canTrigger → bool
-
no setter
-
config
→ LdSubmitConfig<
T, Arg> -
final
- disabled ← bool
-
no getter
- disposed → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- id ↔ String
-
latefinal
- isDisabled → bool
-
no setter
- retryController → LdRetryController
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
↔ LdSubmitState<
T> -
getter/setter pair
-
stateStream
→ Stream<
LdSubmitState< T> > -
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
cancel(
) → Future< void> -
debugForceError(
) → void -
dispose(
) → void -
Discards any resources used by the object.
override
-
init(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
reset(
) → void -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
trigger(
) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited