RetryControllerDto class

Constructors

RetryControllerDto({required int attempt, required Duration? remainingRetryTime, required bool isRetrying, required bool canRetry, required Duration? totalRetryDelay})

Properties

attempt int
final
canRetry bool
final
hashCode int
The hash code for this object.
no setterinherited
isRetrying bool
final
remainingRetryTime Duration?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalRetryDelay Duration?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic> map) RetryControllerDto