SubmitConfigDto class

Constructors

SubmitConfigDto({required bool autoTrigger, required bool allowCancel, required bool allowResubmit, required bool hapticsEnabled, required String? timeout, required LdSubmitCallback? action})

Properties

action LdSubmitCallback?
final
allowCancel bool
final
allowResubmit bool
final
autoTrigger bool
final
hapticsEnabled bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromLdSubmitConfig(LdSubmitConfig config) SubmitConfigDto
fromMap(Map<String, dynamic> map) SubmitConfigDto