SubmitControllerDto class

Constructors

SubmitControllerDto({required String id, required SubmitControllerStateDto state, required String type, required bool canRetry, required bool canRetrigger, required bool allowCancel, required bool allowResubmit, required bool canTrigger, required bool autoTrigger, required bool withHaptics, required String? debugLabel})

Properties

allowCancel bool
final
allowResubmit bool
final
autoTrigger bool
final
canRetrigger bool
final
canRetry bool
final
canTrigger bool
final
debugLabel String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state SubmitControllerStateDto
final
type String
final
withHaptics bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited