SubmitControllerStateDto class
Constructors
- SubmitControllerStateDto({required LdSubmitStateType type, String? error, String? result})
Properties
- error → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- result → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → LdSubmitStateType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromLdSubmitState(
LdSubmitState state) → SubmitControllerStateDto -
fromMap(
Map< String, dynamic> map) → SubmitControllerStateDto