SubmitDevTools class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerController(LdSubmitController controller) → void
toString() String
A string representation of this object.
inherited
unregisterController(LdSubmitController controller) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance SubmitDevTools
no setter