Package class

Package license definition.

Constructors

Package({required String name, required String description, String? homepage, String? repository, required List<String> authors, required String version, String? license, required bool isMarkdown, required bool isSdk, required bool isDirectDependency})
const

Properties

authors → List<String>
Authors
final
description → String
Description
final
hashCode → int
The hash code for this object.
no setterinherited
homepage → String?
Website URL
final
isDirectDependency → bool
Whether the package is direct dependency or not.
final
isMarkdown → bool
Whether the license is in markdown format or not (plain text).
final
isSdk → bool
Whether the package is included in the SDK or not.
final
license → String?
License
final
name → String
Package name
final
repository → String?
Repository URL
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String
Version
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited